@@ -1,4 +1,4 @@
-# Copyright (C) 2022-2024 Hibiki AI Limited <info@hibiki-ai.com>
+# Copyright (C) 2022-2025 Hibiki AI Limited <info@hibiki-ai.com>
 #
 # This file is part of nanonext.
 #
@@ -24,47 +24,46 @@
 #' This function encapsulates a Socket, Dialer and/or Listener, and its
 #' associated methods.
 #'
-#' The Socket may be accessed by \code{$socket}, and the Dialer or Listener by
-#' \code{$dialer[[1]]} or \code{$listener[[1]]} respectively.
+#' The Socket may be accessed by `$socket`, and the Dialer or Listener by
+#' `$dialer[[1]]` or `$listener[[1]]` respectively.
 #'
-#' The object's methods may be accessed by \code{$} e.g. \code{$send()} or
-#' \code{$recv()}. These methods mirror their functional equivalents, with the
-#' same arguments and defaults, apart from that the first argument of the
-#' functional equivalent is mapped to the object's encapsulated socket (or
-#' context, if active) and does not need to be supplied.
+#' The object's methods may be accessed by `$` e.g. `$send()` or `$recv()`.
+#' These methods mirror their functional equivalents, with the same arguments
+#' and defaults, apart from that the first argument of the functional equivalent
+#' is mapped to the object's encapsulated socket (or context, if active) and
+#' does not need to be supplied.
 #'
 #' More complex network topologies may be created by binding further dialers or
-#' listeners using the object's \code{$dial()} and \code{$listen()} methods. The
-#' new dialer/listener will be attached to the object e.g. if the object already
-#' has a dialer, then at \code{$dialer[[2]]} etc.
+#' listeners using the object's `$dial()` and `$listen()` methods. The new
+#' dialer/listener will be attached to the object e.g. if the object already has
+#' a dialer, then at `$dialer[[2]]` etc.
 #'
-#' Note that \code{$dialer_opt()} and \code{$listener_opt()} methods will be
-#' available once dialers/listeners are attached to the object. These methods
-#' get or apply settings for all dialers or listeners equally. To get or apply
-#' settings for individual dialers/listeners, access them directly via
-#' \code{$dialer[[2]]} or \code{$listener[[2]]} etc.
+#' Note that `$dialer_opt()` and `$listener_opt()` methods will be available
+#' once dialers/listeners are attached to the object. These methods get or apply
+#' settings for all dialers or listeners equally. To get or apply settings for
+#' individual dialers/listeners, access them directly via `$dialer[[2]]` or
+#' `$listener[[2]]` etc.
 #'
-#' The methods \code{$opt()}, and also \code{$dialer_opt()} or
-#' \code{$listener_opt()} as may be applicable, will get the requested option if
-#' a single argument 'name' is provided, and will set the value for the option
-#' if both arguments 'name' and 'value' are provided.
+#' The methods `$opt()`, and also `$dialer_opt()` or `$listener_opt()` as may be
+#' applicable, will get the requested option if a single argument `name` is
+#' provided, and will set the value for the option if both arguments `name` and
+#' `value` are provided.
 #'
-#' For Dialers or Listeners not automatically started, the
-#' \code{$dialer_start()} or  \code{$listener_start()} methods will be
-#' available. These act on the most recently created Dialer or Listener
-#' respectively.
+#' For Dialers or Listeners not automatically started, the `$dialer_start()` or
+#' `$listener_start()` methods will be available. These act on the most recently
+#' created Dialer or Listener respectively.
 #'
 #' For applicable protocols, new contexts may be created by using the
-#' \code{$context_open()} method. This will attach a new context at
-#' \code{$context} as well as a \code{$context_close()} method. While a context
-#' is active, all object methods use the context rather than the socket. A new
-#' context may be created by calling \code{$context_open()}, which will replace
-#' any existing context. It is only necessary to use \code{$context_close()} to
-#' close the existing context and revert to using the socket.
+#' `$context_open()` method. This will attach a new context at `$context` as
+#' well as a `$context_close()` method. While a context is active, all object
+#' methods use the context rather than the socket. A new context may be created
+#' by calling `$context_open()`, which will replace any existing context. It is
+#' only necessary to use `$context_close()` to close the existing context and
+#' revert to using the socket.
 #'
 #' @inheritParams socket
 #'
-#' @return A nano object of class \sQuote{nanoObject}.
+#' @return A nano object of class 'nanoObject'.
 #'
 #' @examples
 #' nano <- nano("bus", listen = "inproc://nanonext")
@@ -449,10 +448,6 @@ print.tlsConfig <- function(x, ...) {
 #'
 `$<-.recvAio` <- function(x, name, value) x
 
-#' @export
-#'
-`[[<-.recvAio` <- function(x, i, value) x
-
 #' @export
 #'
 `[.sendAio` <- function(x, i) collect_aio_(x)
@@ -461,10 +456,6 @@ print.tlsConfig <- function(x, ...) {
 #'
 `$<-.sendAio` <- function(x, name, value) x
 
-#' @export
-#'
-`[[<-.sendAio` <- function(x, i, value) x
-
 #' @exportS3Method utils::.DollarNames
 #'
 .DollarNames.nano <- function(x, pattern = "")
