@@ -16,6 +16,7 @@
 
 // nanonext - C level - Async Functions ----------------------------------------
 
+#define NANONEXT_SIGNALS
 #include "nanonext.h"
 
 // internals -------------------------------------------------------------------
@@ -71,6 +72,55 @@ static void raio_complete(void *arg) {
 
 }
 
+static void raio_complete_signal(void *arg) {
+
+  nano_aio *raio = (nano_aio *) arg;
+  nano_cv *ncv = (nano_cv *) raio->next;
+  nng_cv *cv = ncv->cv;
+  nng_mtx *mtx = ncv->mtx;
+
+  int res = nng_aio_result(raio->aio);
+  if (res == 0) {
+    nng_msg *msg = nng_aio_get_msg(raio->aio);
+    raio->data = msg;
+    nng_pipe p = nng_msg_get_pipe(msg);
+    res = - (int) p.id;
+  }
+
+  nng_mtx_lock(mtx);
+  raio->result = res;
+  ncv->condition++;
+  nng_cv_wake(cv);
+  nng_mtx_unlock(mtx);
+
+}
+
+static void raio_complete_interrupt(void *arg) {
+
+  nano_aio *raio = (nano_aio *) arg;
+  int res = nng_aio_result(raio->aio);
+  if (res == 0) {
+    nng_msg *msg = nng_aio_get_msg(raio->aio);
+    raio->data = msg;
+    nng_pipe p = nng_msg_get_pipe(msg);
+    res = - (int) p.id;
+  }
+
+  raio->result = res;
+
+  if (raio->cb != NULL)
+    later2(raio_invoke_cb, raio->cb);
+
+  if (nano_interrupt) {
+#ifdef _WIN32
+    UserBreak = 1;
+#else
+    kill(getpid(), SIGINT);
+#endif
+  }
+
+}
+
 static void iraio_complete(void *arg) {
 
   nano_aio *iaio = (nano_aio *) arg;
@@ -139,11 +189,11 @@ static void iaio_finalizer(SEXP xptr) {
 
 SEXP rnng_aio_result(SEXP env) {
 
-  const SEXP exist = nano_findVarInFrame(env, nano_ValueSymbol);
+  const SEXP exist = Rf_findVarInFrame(env, nano_ValueSymbol);
   if (exist != R_UnboundValue)
     return exist;
 
-  const SEXP aio = nano_findVarInFrame(env, nano_AioSymbol);
+  const SEXP aio = Rf_findVarInFrame(env, nano_AioSymbol);
   if (NANO_PTR_CHECK(aio, nano_AioSymbol))
     Rf_error("object is not a valid Aio");
 
@@ -163,11 +213,11 @@ SEXP rnng_aio_result(SEXP env) {
 
 SEXP rnng_aio_get_msg(SEXP env) {
 
-  const SEXP exist = nano_findVarInFrame(env, nano_ValueSymbol);
+  const SEXP exist = Rf_findVarInFrame(env, nano_ValueSymbol);
   if (exist != R_UnboundValue)
     return exist;
 
-  const SEXP aio = nano_findVarInFrame(env, nano_AioSymbol);
+  const SEXP aio = Rf_findVarInFrame(env, nano_AioSymbol);
   if (NANO_PTR_CHECK(aio, nano_AioSymbol))
     Rf_error("object is not a valid Aio");
 
@@ -233,7 +283,7 @@ SEXP rnng_aio_call(SEXP x) {
 
   switch (TYPEOF(x)) {
   case ENVSXP: ;
-    const SEXP coreaio = nano_findVarInFrame(x, nano_AioSymbol);
+    const SEXP coreaio = Rf_findVarInFrame(x, nano_AioSymbol);
     if (NANO_PTR_CHECK(coreaio, nano_AioSymbol))
       return x;
 
@@ -275,7 +325,7 @@ static SEXP rnng_aio_collect_impl(SEXP x, SEXP (*const func)(SEXP)) {
 
   switch (TYPEOF(x)) {
   case ENVSXP: ;
-    out = nano_findVarInFrame(func(x), nano_ValueSymbol);
+    out = Rf_findVarInFrame(func(x), nano_ValueSymbol);
     if (out == R_UnboundValue) break;
     goto resume;
   case VECSXP: ;
@@ -285,7 +335,7 @@ static SEXP rnng_aio_collect_impl(SEXP x, SEXP (*const func)(SEXP)) {
     for (R_xlen_t i = 0; i < xlen; i++) {
       env = func(NANO_VECTOR(x)[i]);
       if (TYPEOF(env) != ENVSXP) goto exit;
-      env = nano_findVarInFrame(env, nano_ValueSymbol);
+      env = Rf_findVarInFrame(env, nano_ValueSymbol);
       if (env == R_UnboundValue) goto exit;
       SET_VECTOR_ELT(out, i, env);
     }
@@ -320,7 +370,7 @@ SEXP rnng_aio_stop(SEXP x) {
 
   switch (TYPEOF(x)) {
   case ENVSXP: ;
-    const SEXP coreaio = nano_findVarInFrame(x, nano_AioSymbol);
+    const SEXP coreaio = Rf_findVarInFrame(x, nano_AioSymbol);
     if (NANO_PTR_CHECK(coreaio, nano_AioSymbol)) break;
     nano_aio *aiop = (nano_aio *) NANO_PTR(coreaio);
     nng_aio_stop(aiop->aio);
@@ -342,7 +392,7 @@ static int rnng_unresolved_impl(SEXP x) {
   int xc;
   switch (TYPEOF(x)) {
   case ENVSXP: ;
-    const SEXP coreaio = nano_findVarInFrame(x, nano_AioSymbol);
+    const SEXP coreaio = Rf_findVarInFrame(x, nano_AioSymbol);
     if (NANO_PTR_CHECK(coreaio, nano_AioSymbol)) {
       xc = 0; break;
     }
@@ -394,7 +444,7 @@ SEXP rnng_unresolved(SEXP x) {
 static int rnng_unresolved2_impl(SEXP x) {
 
   if (TYPEOF(x) == ENVSXP) {
-    const SEXP coreaio = nano_findVarInFrame(x, nano_AioSymbol);
+    const SEXP coreaio = Rf_findVarInFrame(x, nano_AioSymbol);
     if (NANO_PTR_CHECK(coreaio, nano_AioSymbol))
       return 0;
     nano_aio *aiop = (nano_aio *) NANO_PTR(coreaio);
