@@ -184,8 +184,7 @@ static const R_CallMethodDef callMethods[] = {
   {"rnng_stats_get", (DL_FUNC) &rnng_stats_get, 2},
   {"rnng_status_code", (DL_FUNC) &rnng_status_code, 1},
   {"rnng_stream_close", (DL_FUNC) &rnng_stream_close, 1},
-  {"rnng_stream_dial", (DL_FUNC) &rnng_stream_dial, 3},
-  {"rnng_stream_listen", (DL_FUNC) &rnng_stream_listen, 3},
+  {"rnng_stream_open", (DL_FUNC) &rnng_stream_open, 4},
   {"rnng_strerror", (DL_FUNC) &rnng_strerror, 1},
   {"rnng_subscribe", (DL_FUNC) &rnng_subscribe, 3},
   {"rnng_thread_shutdown", (DL_FUNC) &rnng_thread_shutdown, 0},
