@@ -134,11 +134,11 @@ typedef struct nano_handle_s {
 
 typedef union nano_opt_u {
   char *str;
-  bool b;
+  uint64_t u;
+  size_t s;
   nng_duration d;
   int i;
-  size_t s;
-  uint64_t u;
+  bool b;
 } nano_opt;
 
 typedef struct nano_stream_s {
@@ -208,11 +208,6 @@ typedef struct nano_thread_duo_s {
   nano_cv *cv2;
 } nano_thread_duo;
 
-typedef struct nano_signal_s {
-  nano_cv *cv;
-  int *online;
-} nano_signal;
-
 typedef struct nano_buf_s {
   unsigned char *buf;
   size_t len;
@@ -262,13 +257,8 @@ SEXP R_NewEnv(SEXP, int, int);
 #if R_VERSION < R_Version(4, 5, 0)
 SEXP R_mkClosure(SEXP, SEXP, SEXP);
 #endif
-SEXP nano_findVarInFrame(const SEXP, const SEXP);
 SEXP nano_PreserveObject(const SEXP);
 void nano_ReleaseObject(SEXP);
-void raio_complete_interrupt(void *);
-void raio_complete_signal(void *);
-void sendaio_complete(void *);
-void cv_finalizer(SEXP);
 void dialer_finalizer(SEXP);
 void listener_finalizer(SEXP);
 void socket_finalizer(SEXP);
@@ -277,7 +267,7 @@ void raio_invoke_cb(void *);
 int nano_integer(const SEXP);
 SEXP mk_error(const int);
 SEXP mk_error_data(const int);
-SEXP rawToChar(const unsigned char *, const size_t);
+SEXP nano_raw_char(const unsigned char *, const size_t);
 void nano_serialize(nano_buf *, const SEXP, SEXP);
 SEXP nano_unserialize(unsigned char *, const size_t, SEXP);
 SEXP nano_decode(unsigned char *, const size_t, const uint8_t, SEXP);
@@ -351,8 +341,7 @@ SEXP rnng_sleep(SEXP);
 SEXP rnng_stats_get(SEXP, SEXP);
 SEXP rnng_status_code(SEXP);
 SEXP rnng_stream_close(SEXP);
-SEXP rnng_stream_dial(SEXP, SEXP, SEXP);
-SEXP rnng_stream_listen(SEXP, SEXP, SEXP);
+SEXP rnng_stream_open(SEXP, SEXP, SEXP, SEXP);
 SEXP rnng_strerror(SEXP);
 SEXP rnng_subscribe(SEXP, SEXP, SEXP);
 SEXP rnng_thread_shutdown(void);
