@@ -290,7 +290,7 @@ SEXP rnng_ncurl(SEXP http, SEXP convert, SEXP follow, SEXP method, SEXP headers,
   nng_http_res_get_data(res, &dat, &sz);
 
   if (NANO_INTEGER(convert)) {
-    vec = rawToChar(dat, sz);
+    vec = nano_raw_char(dat, sz);
   } else {
     vec = Rf_allocVector(RAWSXP, sz);
     if (dat != NULL)
@@ -448,14 +448,14 @@ static SEXP rnng_aio_http_impl(SEXP env, const int typ) {
 
   SEXP exist;
   switch (typ) {
-  case 0: exist = nano_findVarInFrame(env, nano_ResultSymbol); break;
-  case 1: exist = nano_findVarInFrame(env, nano_ProtocolSymbol); break;
-  default: exist = nano_findVarInFrame(env, nano_ValueSymbol); break;
+  case 0: exist = Rf_findVarInFrame(env, nano_ResultSymbol); break;
+  case 1: exist = Rf_findVarInFrame(env, nano_ProtocolSymbol); break;
+  default: exist = Rf_findVarInFrame(env, nano_ValueSymbol); break;
   }
   if (exist != R_UnboundValue)
     return exist;
 
-  const SEXP aio = nano_findVarInFrame(env, nano_AioSymbol);
+  const SEXP aio = Rf_findVarInFrame(env, nano_AioSymbol);
 
   nano_aio *haio = (nano_aio *) NANO_PTR(aio);
 
@@ -470,7 +470,7 @@ static SEXP rnng_aio_http_impl(SEXP env, const int typ) {
   SEXP out, vec, rvec, response;
   nano_handle *handle = (nano_handle *) haio->next;
 
-  PROTECT(response = nano_findVarInFrame(env, nano_ResponseSymbol));
+  PROTECT(response = Rf_findVarInFrame(env, nano_ResponseSymbol));
   int chk_resp = response != R_NilValue && TYPEOF(response) == STRSXP;
   const uint16_t code = nng_http_res_get_status(handle->res), relo = code >= 300 && code < 400;
   Rf_defineVar(nano_ResultSymbol, Rf_ScalarInteger(code), env);
@@ -505,7 +505,7 @@ static SEXP rnng_aio_http_impl(SEXP env, const int typ) {
   nng_http_res_get_data(handle->res, &dat, &sz);
 
   if (haio->mode) {
-    vec = rawToChar(dat, sz);
+    vec = nano_raw_char(dat, sz);
   } else {
     vec = Rf_allocVector(RAWSXP, sz);
     if (dat != NULL)
@@ -516,9 +516,9 @@ static SEXP rnng_aio_http_impl(SEXP env, const int typ) {
   Rf_defineVar(nano_AioSymbol, R_NilValue, env);
 
   switch (typ) {
-  case 0: out = nano_findVarInFrame(env, nano_ResultSymbol); break;
-  case 1: out = nano_findVarInFrame(env, nano_ProtocolSymbol); break;
-  default: out = nano_findVarInFrame(env, nano_ValueSymbol); break;
+  case 0: out = Rf_findVarInFrame(env, nano_ResultSymbol); break;
+  case 1: out = Rf_findVarInFrame(env, nano_ProtocolSymbol); break;
+  default: out = Rf_findVarInFrame(env, nano_ValueSymbol); break;
   }
   return out;
 
@@ -694,7 +694,7 @@ SEXP rnng_ncurl_transact(SEXP session) {
   nng_http_res_get_data(handle->res, &dat, &sz);
 
   if (haio->mode) {
-    vec = rawToChar(dat, sz);
+    vec = nano_raw_char(dat, sz);
   } else {
     vec = Rf_allocVector(RAWSXP, sz);
     if (dat != NULL)
