@@ -21,6 +21,14 @@
 
 // aio completion callbacks ----------------------------------------------------
 
+static void sendaio_complete(void *arg) {
+
+  nng_aio *aio = ((nano_saio *) arg)->aio;
+  if (nng_aio_result(aio))
+    nng_msg_free(nng_aio_get_msg(aio));
+
+}
+
 static void request_complete(void *arg) {
 
   nano_aio *raio = (nano_aio *) arg;
@@ -136,6 +144,16 @@ static void pipe_cb_monitor(nng_pipe p, nng_pipe_ev ev, void *arg) {
 
 // finalizers ------------------------------------------------------------------
 
+static void cv_finalizer(SEXP xptr) {
+
+  if (NANO_PTR(xptr) == NULL) return;
+  nano_cv *xp = (nano_cv *) NANO_PTR(xptr);
+  nng_cv_free(xp->cv);
+  nng_mtx_free(xp->mtx);
+  R_Free(xp);
+
+}
+
 static void request_finalizer(SEXP xptr) {
 
   if (NANO_PTR(xptr) == NULL) return;
@@ -466,7 +484,7 @@ SEXP rnng_set_promise_context(SEXP x, SEXP ctx) {
   if (TYPEOF(x) != ENVSXP)
     return R_NilValue;
 
-  SEXP aio = nano_findVarInFrame(x, nano_AioSymbol);
+  SEXP aio = Rf_findVarInFrame(x, nano_AioSymbol);
   if (NANO_PTR_CHECK(aio, nano_AioSymbol))
     return R_NilValue;
 
