@@ -334,7 +334,7 @@ SEXP rnng_wait_thread_create(SEXP x) {
   const SEXPTYPE typ = TYPEOF(x);
   if (typ == ENVSXP) {
 
-    const SEXP coreaio = nano_findVarInFrame(x, nano_AioSymbol);
+    const SEXP coreaio = Rf_findVarInFrame(x, nano_AioSymbol);
     if (NANO_PTR_CHECK(coreaio, nano_AioSymbol))
       return x;
 
