@@ -95,11 +95,9 @@ test_class("recvAio", raio <- n$recv_aio(timeout = 500))
 test_print(raio)
 test_equal(nchar(call_aio(raio)[["value"]]), 10000L)
 raio$newfield <- "doesnotwork"
-raio[["newfield"]] <- "doesnotwork"
 test_null(raio$newfield)
 test_class("sendAio", saio <- n$send_aio(c(1.1, 2.2), mode = "raw", timeout = 500))
 saio$newfield <- "doesnotwork"
-saio[["newfield"]] <- "doesnotwork"
 test_null(saio$newfield)
 test_type("logical", unresolved(saio))
 test_type("logical", .unresolved(saio))
@@ -382,6 +380,7 @@ test_true(wait(cv))
 test_equal(length(pipes <- read_monitor(m)), 2L)
 test_zero(send_aio(poly, "one", timeout = 500, pipe = pipes[1L])[])
 test_zero(send(poly, "two", block = 500, pipe = pipes[2L]))
+test_type("integer", send(poly, "two", block = FALSE, pipe = pipes[2L]))
 test_type("character", recv(poly1, block = 500))
 test_type("character", recv(poly2, block = 500))
 test_zero(reap(poly2))
@@ -456,7 +455,7 @@ test_error(stream(dial = "wss://127.0.0.1:5555", tls = "wrong"), "valid TLS")
 test_error(stream(listen = "errorValue3"), "argument")
 test_error(stream(listen = "inproc://notsup"), "Not supported")
 test_error(stream(listen = "errorValue3", tls = "wrong"), "valid TLS")
-test_error(stream(), "specify")
+test_error(stream(), "specify a URL")
 
 test_type("character", ver <- nng_version())
 test_equal(length(ver), 2L)
@@ -611,6 +610,8 @@ if (promises) test_class("recvAio", r2 <- recv_aio(s, timeout = 1L))
 if (promises) test_true(promises::is.promising(call_aio(r2)))
 if (promises) test_true(promises::is.promise(promises::then(r2, identity, identity)))
 if (promises) test_true(promises::is.promising(call_aio(r)))
+if (promises) test_type("integer", send(s1, "promises test2\n", block = 500L))
+if (promises) test_true(promises::is.promise(promises::then(call_aio(recv_aio(s, timeout = 500L)), identity, identity)))
 if (promises) test_true(is_aio(n <- ncurl_aio("https://postman-echo.com/get")))
 if (promises) test_true(promises::is.promise(promises::then(n, identity, identity)))
 if (promises) test_true(promises::is.promising(call_aio(n)))
